#
# spec file for package pgn-extract
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2010 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define mver    25-01
Name:           pgn-extract
Version:        25.01
Release:        1.1
Summary:        A CLI program for manipulating PGN files
License:        GPL-3.0-or-later
Group:          Amusements/Games/Board/Chess
URL:            https://www.cs.kent.ac.uk/people/staff/djb/pgn-extract/
Source0:        https://www.cs.kent.ac.uk/~djb/pgn-extract/pgn-extract-%{mver}.tgz
Source100:      %{name}.changes
# PATCH-FIX-OPENSUSE pgn-extract-set_eco.pgn_path.patch
Patch0:         pgn-extract-set_eco.pgn_path.patch
# PATCH-FIX-OPENSUSE pgn-extract-no-buildtime.patch
Patch1:         pgn-extract-no-buildtime.patch

%description
This is a command-line program for manipulating chess games recorded
in the Portable Game Notation (PGN).
Extracted games may be written out either including or excluding
comments, NAGs, variations, move numbers, tags and/or results.
Games may be given ECO classifications derived from the accompanying
file %{_datadir}/%{name}/eco.pgn, or a customised version provided
by the user.

For a full description of pgn-extract's functionality see
%{_docdir}/%{name}/help.html.

%prep
%autosetup -p1 -n %{name}

%build
CFLAGS="%{optflags}" make

%install
# install the binary
install -D -m 0755 %{name} %{buildroot}%{_bindir}/%{name}
# install the default eco.pgn file
install -D -m 0644 eco.pgn %{buildroot}%{_datadir}/%{name}/eco.pgn

%files
%license COPYING
%doc help.html
%{_bindir}/%{name}
%{_datadir}/%{name}

%changelog
* Sun Jan 12 2025 Andrea Manzini <andrea.manzini@suse.com>
- Update to 25.01
  * bug fix for repetition detection (--repetition);
  * find games whether the winner is either the higher or lower rated player
    (--lowerratedwinner and --higherratedwinner);
  * extend -v to match move sequences anywhere in a game, not just at the
    start (--vanywhere);
  * find games played at odds (--odds).
* Sun Jul 21 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 24.11
  * Bug fix for material matches with Chess960 games involving castling.
  * Bug fix for -n when used with tag matching.
  * Bug fix for tag matching with relational operators.
  * Bug fix for position matching via -z. Games with FEN tags in which black
    was to move had colours swapped when matching.
  * New options --commented, --insufficient and --suppressmatched.
  * Added stdout as an output for -n.
  * EloDiff pseudo-tag added.
  * Relational operator available for non-numeric tag values.
* Thu Jun 13 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 24.10
  * Bug fix for -n resulting from failing to completely check
    the validity of non-matching games.
* Wed Jun  5 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 24.09
  * For tag matches using <> in which all matches are negative,
    the absence of that tag from a game will result in the game being retained.
  * Bug fix for relational operators matching numeric tags.
    Comparisons are now 'anded' rather than 'ored'.
  * Bug fix affecting material matches for games with a FEN tag in which Black is to move.
  * Added options --commented , --insufficient, --suppressmatched and -n stdout
  * <> relational operator now available for non-numeric tag values.
  * EloDiff pseudo-tag added for matching differences in Elo rating between opponents
  * Detect wrong to-move status in FEN string when the other side is in check.
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Fri Dec 23 2022 Andrea Manzini <andrea.manzini@suse.com>
- Update to 22.11
  * Bug fixes
  * added --firstgame and --gamelimit
  * Regular expressions added to tag matching via -t
  * added --seventyfive , --repetition5
  * Added recognition of some en passant indicators in the input. They are deleted in the output version.
  * Added recognition of single-line comments.
  * Added -Wfen, --deletesamesetup, --addfencastling , --detag
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 20.02
  * Added --linenumbers
  * Added --fixtagstrings.
  * Date matches with -t and -T extended to match on month and day
    as well as year.
  * Added --wtm and --btm.
  * Added limited relational TimeControl matching with -t
  * Added missing 'ep' for en passant moves with -Wxlalg and -Wxolalg.
  * Bug fix to eliminate illegal pawn moves in long algebraic notation.
  * Added --startply.
  * Added --fenpattern, --fenpatterni, --materialy and --materialz
    as command-line arguments.
  * Delete NAGs appearing before the first move of a game.
- Rebase patches:
  * pgn-extract-no-buildtime.patch
  * pgn-extract-set_eco.pgn_path.patch
* Sun Mar 29 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.04:
  * Improved --repetition so that it does not give false
    positives when castling rights or who is to move are
    different.
  * Retain next move number rather than resetting to 1
    with --dropply and --dropbefore.
  * Fixed a memory error in v18-10
  * Added --xroster to suppress tags that are not required with -R.
  * Missing SetUp tags no longer elicit an error message as this
    contravention of the standard is so common.
  * Negative value accepted with --dropply to indicates plies
    to be retained at the end of the game.
- Rebase patches:
  * pgn-extract-set_eco.pgn_path.patch
  * pgn-extract-no-buildtime.patch
* Thu Nov 15 2018 aloisio@gmx.com
- Update to version 18.10 (no changelog supplied)
- Refreshed pgn-extract-no-buildtime.patch
* Thu Nov 15 2018 aloisio@gmx.com
- Modified pgn-extract-no-buildtime.patch. Previous patch left a
  dangling '%%s' in the format string which causes the app to crash
  when called with '-h' (courtesy of Rolf Offermanns)
  Fixes (boo#1116207)
* Sun Jan 28 2018 aloisio@gmx.com
- Update to version 17.55
- Refreshed pgn-extract-set_eco.pgn_path.patch and
  pgn-extract-no-buildtime.patch
* Sun Feb  7 2010 packman@links2linux.de - 16.7
- initial package, version 16.7
